@@ -5,5 +5,6 @@ from .jsons_handler import JsonsHandler
 from .pickle_handler import PickleHandler
 from .yaml_handler import YamlHandler
 from .csv_handler import CsvHandler
+from .texts_handler import TextsHandler
 
-__all__ = ['BaseFileHandler', 'JsonHandler','JsonsHandler', 'PickleHandler', 'YamlHandler','CsvHandler']
+__all__ = ['BaseFileHandler', 'JsonHandler','JsonsHandler', 'PickleHandler', 'YamlHandler','CsvHandler','TextsHandler']
